mailr5322 - /1.3/specific_fns/consistency_tests.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by sebastien . morin . 1 on April 04, 2008 - 17:25:
Author: semor
Date: Fri Apr  4 17:25:14 2008
New Revision: 5322

URL: http://svn.gna.org/viewcvs/relax?rev=5322&view=rev
Log:
Partially fixed more code so the consistency tests system test can go further 
before failure...


Modified:
    1.3/specific_fns/consistency_tests.py

Modified: 1.3/specific_fns/consistency_tests.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/specific_fns/consistency_tests.py?rev=5322&r1=5321&r2=5322&view=diff
==============================================================================
--- 1.3/specific_fns/consistency_tests.py (original)
+++ 1.3/specific_fns/consistency_tests.py Fri Apr  4 17:25:14 2008
@@ -268,23 +268,23 @@
 
 
     def overfit_deselect(self):
-        """Function for deselecting residues without sufficient data to 
support calculation"""
+        """Function for deselecting spins without sufficient data to support 
calculation"""
 
         # Test if the sequence data is loaded.
         if not exists_mol_res_spin_data():
             raise RelaxNoSequenceError
 
-        # Loop over residue data:
-        for residue in relax_data_store.res[run]:
+        # Loop over spin data:
+        for spin in spin_loop():
 
             # Check for sufficient data
-            if not hasattr(residue, 'relax_data'):
-                residue.select = 0
+            if not hasattr(spin, 'relax_data'):
+                spin.select = 0
                 continue
 
             # Require 3 or more data points
-            if len(residue.relax_data) < 3:
-                residue.select = 0
+            if len(spin.relax_data) < 3:
+                spin.select = 0
                 continue
 
 




Related Messages


Powered by MHonArc, Updated Fri Apr 04 17:40:12 2008